@@ -132,7 +132,7 @@ class Constraint(object):
                    'less_or_equal', 'in_range', 'valid_values', 'length',
                    'min_length', 'max_length', 'pattern')
 
-    def __new__(cls, property_name, property_type, constraint):
+    def __new__(cls, property_name=None, property_type=None, constraint=None):
         if cls is not Constraint:
             return super(Constraint, cls).__new__(cls)
 
@@ -278,8 +278,8 @@ class GreaterOrEqual(Constraint):
                                              'comparable values.')))
 
     def _is_valid(self, value):
-        if toscaparser.functions.is_function(value) or \
-           value >= self.constraint_value:
+        if value is not None and (toscaparser.functions.is_function(value) or
+                                  value >= self.constraint_value):
             return True
         return False
 
@@ -503,7 +503,7 @@ class MinLength(Constraint):
 
     valid_types = (int, )
 
-    valid_prop_types = (Schema.STRING, Schema.MAP)
+    valid_prop_types = (Schema.STRING, Schema.MAP, Schema.LIST)
 
     def __init__(self, property_name, property_type, constraint):
         super(MinLength, self).__init__(property_name, property_type,
@@ -514,7 +514,7 @@ class MinLength(Constraint):
                                              'expects an integer.')))
 
     def _is_valid(self, value):
-        if ((isinstance(value, str) or isinstance(value, dict)) and
+        if (isinstance(value, (str, dict, list)) and
            len(value) >= self.constraint_value):
             return True
 
@@ -538,7 +538,7 @@ class MaxLength(Constraint):
 
     valid_types = (int, )
 
-    valid_prop_types = (Schema.STRING, Schema.MAP)
+    valid_prop_types = (Schema.STRING, Schema.MAP, Schema.LIST)
 
     def __init__(self, property_name, property_type, constraint):
         super(MaxLength, self).__init__(property_name, property_type,
@@ -549,7 +549,7 @@ class MaxLength(Constraint):
                                              'expects an integer.')))
 
     def _is_valid(self, value):
-        if ((isinstance(value, str) or isinstance(value, dict)) and
+        if (isinstance(value, (str, dict, list)) and
            len(value) <= self.constraint_value):
             return True
 
@@ -608,7 +608,7 @@ constraint_mapping = {
     Constraint.MIN_LENGTH: MinLength,
     Constraint.MAX_LENGTH: MaxLength,
     Constraint.PATTERN: Pattern
-    }
+}
 
 
 def get_constraint_class(type):
