@@ -15,7 +15,6 @@ import dateutil.parser
 import logging
 import numbers
 import re
-import six
 
 # from toscaparser.elements import constraints
 from toscaparser.common.exception import ExceptionCollector
@@ -64,7 +63,7 @@ def validate_float(value):
 
 
 def validate_string(value):
-    if not isinstance(value, six.string_types):
+    if not isinstance(value, str):
         ExceptionCollector.appendException(
             ValueError(_('"%s" is not a string.') % value))
     return value
@@ -165,11 +164,11 @@ def validate_timestamp(value):
 
 class TOSCAVersionProperty(object):
 
-    VERSION_RE = re.compile('^(?P<major_version>([0-9][0-9]*))'
-                            '(\.(?P<minor_version>([0-9][0-9]*)))?'
-                            '(\.(?P<fix_version>([0-9][0-9]*)))?'
-                            '(\.(?P<qualifier>([0-9A-Za-z]+)))?'
-                            '(\-(?P<build_version>[0-9])*)?$')
+    VERSION_RE = re.compile(r'^(?P<major_version>([0-9][0-9]*))'
+                            r'(\.(?P<minor_version>([0-9][0-9]*)))?'
+                            r'(\.(?P<fix_version>([0-9][0-9]*)))?'
+                            r'(\.(?P<qualifier>([0-9A-Za-z]+)))?'
+                            r'(\-(?P<build_version>[0-9])*)?$')
 
     def __init__(self, version):
         self.version = str(version)
@@ -180,7 +179,7 @@ class TOSCAVersionProperty(object):
             return
         ver = match.groupdict()
         if self.version in ['0', '0.0', '0.0.0']:
-            log.warning(_('Version assumed as not provided'))
+            log.warning('Version assumed as not provided')
             self.version = None
         self.minor_version = ver['minor_version']
         self.major_version = ver['major_version']
@@ -198,8 +197,8 @@ class TOSCAVersionProperty(object):
         """
 
         if self.minor_version is None and self.build_version is None and \
-            value != '0':
-            log.warning(_('Minor version assumed "0".'))
+                value != '0':
+            log.warning('Minor version assumed "0".')
             self.version = '.'.join([value, '0'])
         return value
 
